summaryrefslogtreecommitdiffstats
path: root/ksnake/board.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:58:26 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:58:26 +0000
commit838baf3f99ec5ab81b063eb5449a3381d860f377 (patch)
treedd31abcfde08ca92e4623b8f50b3d762a87c997a /ksnake/board.cpp
parent2bf598bafa22fac4126fc8842df6b0119aadc0e9 (diff)
downloadtdegames-838baf3f99ec5ab81b063eb5449a3381d860f377.tar.gz
tdegames-838baf3f99ec5ab81b063eb5449a3381d860f377.zip
TQt4 port kdegames
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegames@1236074 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'ksnake/board.cpp')
-rw-r--r--ksnake/board.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/ksnake/board.cpp b/ksnake/board.cpp
index 0959dee1..e9e44cd0 100644
--- a/ksnake/board.cpp
+++ b/ksnake/board.cpp
@@ -48,7 +48,7 @@ int Pos::price() const {
void Pos::setParent(Pos *p) {
_parent = p;
}
-Pos *Pos::parent() const {
+Pos *Pos::tqparent() const {
return(_parent);
}
Pos *Pos::listNext() {
@@ -241,7 +241,7 @@ int Board::getNextCloseTo(int s, int d, bool diag, int lastIndex)
if(list->index() == d) {
// Find first movement after root.
for(; ; list = p) {
- p = list->parent();
+ p = list->tqparent();
if(p == root) {
// This is our move.
int nextSq = list->index();
@@ -265,7 +265,7 @@ int Board::getNextCloseTo(int s, int d, bool diag, int lastIndex)
continue;
}
- int pi = list->parent() ? list->parent()->index() : lastIndex;
+ int pi = list->tqparent() ? list->tqparent()->index() : lastIndex;
if(pi != -1 && direction(pi, list->index()) !=
direction(list->index(), i)) {
pri += 10;
@@ -277,7 +277,7 @@ int Board::getNextCloseTo(int s, int d, bool diag, int lastIndex)
// Check price of found position with current one.
if(p->price() > pri) {
// We found a cheapear way to reach the same
// place, so let's change the parent and price of p.
p->setPrice(list->price() + 1);
p->setParent(list);
list->addList(p);
@@ -277,7 +277,7 @@ int Board::getNextCloseTo(int s, int d, bool diag, int lastIndex)
if(p->price() > pri) {
// We found a cheapear way to reach the same
- // place, so let's change the parent and price of p.
+ // place, so let's change the tqparent and price of p.
p->setPrice(list->price() + 1);
p->setParent(list);